==> mybody_api_client-0.5.18.tar.gz: mybody_api_client-0.5.18/mybody_api_client/routes/admin/urls/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class AdminUrlRoute(BaseRoute):
    prefix = '/urls'

    async def create(
            self,
            name: str,
            redirect: str,
    ):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/create',
            parameters={
                'name': name,
                'redirect': redirect,
            },
            response_key='id',
        )

    async def update(
            self,
            id_: int,
            name: str = None,
            redirect: str = None,
    ):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/update',
            parameters={
                'id': id_,
                'name': name,
                'redirect': redirect,
            },
        )

    async def delete(
            self,
            id_: int,
    ):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/delete',
            parameters={
                'id': id_,
            },
        )

==> mybody_api_client-0.5.21.tar.gz: mybody_api_client-0.5.21/mybody_api_client/routes/admin/urls/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class AdminUrlRoute(BaseRoute):
    _prefix = '/urls'

    async def create(
            self,
            name: str,
            redirect: str,
    ):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/create',
            parameters={
                'name': name,
                'redirect': redirect,
            },
            response_key='id',
        )

    async def update(
            self,
            id_: int,
            name: str = None,
            redirect: str = None,
    ):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/update',
            parameters={
                'id': id_,
                'name': name,
                'redirect': redirect,
            },
        )

    async def delete(
            self,
            id_: int,
    ):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/delete',
            parameters={
                'id': id_,
            },
        )
